library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

entity FTDI is Port( 
  -- FTDI-Interface
  Data:  inout STD_LOGIC_VECTOR (7 downto 0); -- Daten zum FTDI, bidirektional
  RXF:      in STD_LOGIC;                     -- RX-Flag
  TXE:      in STD_LOGIC;                     -- TX enable
  RD:      out STD_LOGIC;                     -- Read
  WR:      out STD_LOGIC;                     -- Write
  CLK:      in STD_LOGIC;                     -- Clock from FTDI
  OE:      out STD_LOGIC;                     -- Output enable
  -- Controller-Interface
--RST:      in STD_LOGIC;                     -- Reset
--CLKOUT:  out STD_LOGIC;                     -- Clock to other logic
--STA:     out STD_LOGIC;                     -- Start-Flag
--TXF:      in STD_LOGIC;                     -- TX-Flag
--DataIn:   in STD_LOGIC_VECTOR (7 downto 0); -- Daten vom "Controller"
--DataOut: out STD_LOGIC_VECTOR (7 downto 0); -- Daten zum "Controller"
  Dummy:    in STD_LOGIC);
end FTDI;

architecture Behavioral of FTDI is
  type TBuf is array(0 to 8) of STD_LOGIC_VECTOR(7 downto 0);
  type TFTDIStatus is ( cIDLE, cREAD, cWRITE );

  signal FTDIStatus: TFTDIStatus;
  signal CmdBuf: TBuf;
  signal CmdLen: STD_LOGIC_VECTOR(2 downto 0);
begin
  --------------------------------------------------------------------------------
  FDTI_Proc: Process(RST, CLK)
  begin
    if RST = '0' then
      FTDIStatus <= cIdle;
      CmdBuf(0) <= x"00"; -- CMD 1
      CmdBuf(1) <= x"00"; -- ADR 1
      CmdBuf(2) <= x"00"; -- ADR 2
      CmdBuf(3) <= x"00"; -- ADR 3
      CmdBuf(4) <= x"00"; -- ADR 4
      CmdBuf(5) <= x"00"; -- ADR 5
      CmdBuf(6) <= x"30"; -- CMD 2
      CmdLen    <= x"07"; -- 7 Bytes
    elsif CLK'event then
      case FTDIStatus is
        when cIDLE  => if RXF = '0' then
                         FTDIStatus <= cREAD;
                         Data <= (others=>'Z');
                         DataOut <= Data;
                       elsif TXF = '1' AND TXE = '0' then
                         FTDIStatus <= cWRITE;
                         Data <= DataIn;
                       end if;
        when cREAD  => if RXF = '1'              then FTDIStatus := cIDLE; end if;
        when cWRITE => if TXE = '1' OR TXF = '0' then FTDIStatus := cIDLE; end if;
      end case;
    end if;
  end process;
  --------------------------------------------------------------------------------
end Behavioral;

